@@ -19,9 +19,12 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
+import re
+
 from apitools.base.py import encoding as apitools_encoding
-from apitools.base.py import exceptions as api_exceptions
+from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.util import apis
+from googlecloudsdk.api_lib.util import exceptions as api_lib_exceptions
 from googlecloudsdk.api_lib.util import waiter
 from googlecloudsdk.command_lib.run import exceptions
 from googlecloudsdk.core import resources
@@ -42,6 +45,8 @@ _POLLING_TIMEOUT_MS = 30 * 60 * 1000
 # Max wait time between poll retries before timing out
 _RETRY_TIMEOUT_MS = 1000
 
+_LOCATION_ERROR_REGEX = re.compile(r'Location [\w-]+ is not found')
+
 
 def GetMessages():
   """Returns the messages module for the Runapps API.
@@ -67,7 +72,9 @@ def GetApplication(client, app_ref):
       name=app_ref.RelativeName())
   try:
     return client.projects_locations_applications.Get(request)
-  except api_exceptions.HttpNotFoundError:
+  except apitools_exceptions.HttpForbiddenError as e:
+    _HandleLocationError(e)
+  except apitools_exceptions.HttpNotFoundError:
     return None
 
 
@@ -105,7 +112,9 @@ def GetApplicationStatus(client, app_ref, resource_name=None):
       name=app_ref.RelativeName(), readMask=read_mask)
   try:
     return client.projects_locations_applications.GetStatus(request)
-  except api_exceptions.HttpNotFoundError:
+  except apitools_exceptions.HttpForbiddenError as e:
+    _HandleLocationError(e)
+  except apitools_exceptions.HttpNotFoundError:
     return None
 
 
@@ -171,6 +180,28 @@ def CreateDeployment(client, app_ref, deployment, validate_only=False):
       )
 
 
+def GetDeployment(client, deployment_name):
+  """Calls GetDeployment API of Runapps.
+
+  Args:
+    client: GAPIC API client, the api client to use.
+    deployment_name: str, the canonical name of the deployment.  For example:
+      projects/<project>/locations/<location>/applications/<app>/deployment/<id>
+
+  Returns:
+    run_apps.v1alpha1.Deployment, the Deployment object.  None is returned if
+      the deployment cannot be found.
+  """
+  try:
+    return client.projects_locations_applications_deployments.Get(
+        client.MESSAGES_MODULE
+        .RunappsProjectsLocationsApplicationsDeploymentsGetRequest(
+            name=deployment_name)
+        )
+  except apitools_exceptions.HttpNotFoundError:
+    return None
+
+
 def WaitForApplicationOperation(client, operation):
   """Waits for an operation to complete.
 
@@ -271,3 +302,21 @@ def GetDeploymentOperationMetadata(messages, operation):
   return apitools_encoding.PyValueToMessage(
       messages.DeploymentOperationMetadata,
       apitools_encoding.MessageToPyValue(operation.metadata))
+
+
+def _HandleLocationError(error):
+  """Get the metadata message for the deployment operation.
+
+  Args:
+    error: The original HttpError.
+
+  Raises:
+    UnsupportedIntegrationsLocationError if it's location error. Otherwise
+    raise the original error.
+  """
+  parsed_err = api_lib_exceptions.HttpException(error)
+  if _LOCATION_ERROR_REGEX.match(parsed_err.payload.status_message):
+    raise exceptions.UnsupportedIntegrationsLocationError(
+        'Currently, this feature is only available in regions asia-east1, '
+        'us-central1, us-east1, us-west1, europe-west1 and europe-west4.')
+  raise error
