@@ -22,8 +22,10 @@ from apitools.base.py import exceptions as api_exceptions
 from googlecloudsdk.api_lib.util import apis
 from googlecloudsdk.api_lib.util import exceptions
 from googlecloudsdk.api_lib.util import waiter
+from googlecloudsdk.api_lib.workflows import cache
 from googlecloudsdk.api_lib.workflows import poller_utils
 from googlecloudsdk.calliope import base
+from googlecloudsdk.command_lib.util.apis import arg_utils
 from googlecloudsdk.command_lib.util.args import labels_util
 from googlecloudsdk.command_lib.workflows import flags
 from googlecloudsdk.core import resources
@@ -38,6 +40,8 @@ def ReleaseTrackToApiVersion(release_track):
     return 'v1alpha1'
   elif release_track == base.ReleaseTrack.BETA:
     return 'v1beta'
+  elif release_track == base.ReleaseTrack.GA:
+    return 'v1'
   else:
     raise UnsupportedReleaseTrackError(release_track)
 
@@ -102,8 +106,17 @@ class WorkflowsClient(object):
         workflow=workflow)
     return self._service.Patch(patch_req)
 
-  def BuildWorkflowFromArgs(self, args):
-    """Create a workflow from command-line arguments."""
+  def BuildWorkflowFromArgs(self, args, release_track):
+    """Creates a workflow from command-line arguments.
+
+    Args:
+      args: The arguments of the gcloud command.
+      release_track: The gcloud release track used in the command.
+
+    Returns:
+      workflow: The consturcted Workflow message from the passed in arguments.
+      updated_fields: The workflow fields that are updated.
+    """
     workflow = self.messages.Workflow()
     updated_fields = []
     flags.SetSource(args, workflow, updated_fields)
@@ -112,6 +125,20 @@ class WorkflowsClient(object):
     labels = labels_util.ParseCreateArgs(args,
                                          self.messages.Workflow.LabelsValue)
     flags.SetLabels(labels, workflow, updated_fields)
+    if release_track == base.ReleaseTrack.GA:
+      flags.SetKmsKey(args, workflow, updated_fields)
+      if args.IsSpecified('call_log_level'):
+        call_log_level_enum = self.messages.Workflow.CallLogLevelValueValuesEnum
+        workflow.callLogLevel = arg_utils.ChoiceToEnum(
+            args.call_log_level,
+            call_log_level_enum,
+            valid_choices=[
+                'none',
+                'log-all-calls',
+                'log-errors-only',
+                'log-none',
+            ],
+        )
     return workflow, updated_fields
 
   def WaitForOperation(self, operation, workflow_ref):
@@ -134,6 +161,42 @@ class WorkflowExecutionClient(object):
     self.messages = self.client.MESSAGES_MODULE
     self._service = self.client.projects_locations_workflows_executions
 
+  def Create(self, workflow_ref, data, call_log_level=None, labels=None):
+    """Creates a Workflow execution.
+
+    Args:
+      workflow_ref: Resource reference to the Workflow to execute.
+      data: Argments to use for executing the workflow.
+      call_log_level: Level of call logging to apply during execution.
+      labels: Labels associated to the execution.
+
+    Returns:
+      Execution: The workflow execution.
+    """
+    execution = self.messages.Execution()
+    execution.argument = data
+    if labels is not None:
+      execution.labels = labels
+    if call_log_level is not None and call_log_level != 'none':
+      call_log_level_enum = self.messages.Execution.CallLogLevelValueValuesEnum
+      execution.callLogLevel = arg_utils.ChoiceToEnum(
+          call_log_level,
+          call_log_level_enum,
+          valid_choices=[
+              'none',
+              'log-all-calls',
+              'log-errors-only',
+              'log-none',
+          ],
+      )
+    create_req = self.messages.WorkflowexecutionsProjectsLocationsWorkflowsExecutionsCreateRequest(
+        parent=workflow_ref.RelativeName(),
+        execution=execution)
+    try:
+      return self._service.Create(create_req)
+    except api_exceptions.HttpError as e:
+      raise exceptions.HttpException(e, error_format='{message}')
+
   def Get(self, execution_ref):
     """Gets a workflow execution.
 
@@ -144,6 +207,9 @@ class WorkflowExecutionClient(object):
       Workflow: The workflow execution if it exists, an error exception
       otherwise.
     """
+    if execution_ref is None:
+      execution_ref = cache.get_cached_execution_id()
+
     get_req = self.messages.WorkflowexecutionsProjectsLocationsWorkflowsExecutionsGetRequest(
         name=execution_ref.RelativeName())
     try:
@@ -153,6 +219,10 @@ class WorkflowExecutionClient(object):
 
   def WaitForExecution(self, execution_ref):
     """Waits until the given execution is complete or the maximum wait time is reached."""
+
+    if execution_ref is None:
+      execution_ref = cache.get_cached_execution_id()
+
     poller = poller_utils.ExecutionsPoller(workflow_execution=self)
     progress_string = 'Waiting for execution [{}] to complete'.format(
         execution_ref.Name())
