@@ -24,11 +24,10 @@ from __future__ import unicode_literals
 import contextlib
 import functools
 import multiprocessing
-import os
 import sys
 import threading
 
-from googlecloudsdk.api_lib.storage import patch_gcs_messages
+from googlecloudsdk.api_lib.storage.gcs_json import patch_apitools_messages
 from googlecloudsdk.command_lib import crash_handling
 from googlecloudsdk.command_lib.storage import encryption_util
 from googlecloudsdk.command_lib.storage import errors
@@ -36,6 +35,7 @@ from googlecloudsdk.command_lib.storage.tasks import task
 from googlecloudsdk.command_lib.storage.tasks import task_buffer
 from googlecloudsdk.command_lib.storage.tasks import task_graph as task_graph_module
 from googlecloudsdk.command_lib.storage.tasks import task_status
+from googlecloudsdk.core import execution_utils
 from googlecloudsdk.core import log
 from googlecloudsdk.core.console import console_io
 from googlecloudsdk.core.credentials import creds_context_managers
@@ -45,7 +45,7 @@ from six.moves import queue
 
 
 # TODO(b/171296237): Remove this when fixes are submitted in apitools.
-patch_gcs_messages.patch()
+patch_apitools_messages.patch()
 
 
 if sys.version_info.major == 2:
@@ -129,7 +129,7 @@ class SharedProcessContext:
   def __init__(self):
     if multiprocessing_context.get_start_method() == 'fork':
       return
-    self._environment_variables = os.environ.copy()
+    self._environment_variables = execution_utils.GetToolEnv()
     self._creds_context_manager = (
         creds_context_managers.CredentialProvidersManager())
     self._key_store = encryption_util._key_store
@@ -138,13 +138,22 @@ class SharedProcessContext:
     if multiprocessing_context.get_start_method() == 'fork':
       return
 
-    os.environ.update(self._environment_variables)
+    self._environment_context_manager = execution_utils.ReplaceEnv(
+        **self._environment_variables)
+
+    self._environment_context_manager.__enter__()
     self._creds_context_manager.__enter__()
     encryption_util._key_store = self._key_store
 
+    # Passing None causes log settings to be refreshed based on property values.
+    log.SetUserOutputEnabled(None)
+    log.SetVerbosity(None)
+
   def __exit__(self, exc_type, exc_value, exc_traceback):
     if multiprocessing_context.get_start_method() == 'fork':
       return
+    self._environment_context_manager.__exit__(
+        exc_type, exc_value, exc_traceback)
     self._creds_context_manager.__exit__(exc_type, exc_value, exc_traceback)
 
 
@@ -179,10 +188,17 @@ def _thread_worker(task_queue, task_output_queue, task_status_queue,
       task_execution_error = exception
       log.error(exception)
       log.debug(exception, exc_info=sys.exc_info())
-      if task_wrapper.task.report_error:
+
+      if isinstance(exception, errors.FatalError):
         task_output = task.Output(
             additional_task_iterators=None,
             messages=[task.Message(topic=task.Topic.FATAL_ERROR, payload={})])
+      elif task_wrapper.task.change_exit_code:
+        task_output = task.Output(
+            additional_task_iterators=None,
+            messages=[
+                task.Message(topic=task.Topic.CHANGE_EXIT_CODE, payload={})
+            ])
       else:
         task_output = None
     # pylint: enable=broad-except
@@ -369,6 +385,7 @@ class TaskGraphExecutor:
     self.thread_exception = None
     self.thread_exception_lock = threading.Lock()
 
+    self._accepting_new_tasks = True
     self._exit_code = 0
 
   def _add_worker_process(self):
@@ -384,7 +401,7 @@ class TaskGraphExecutor:
     and adding them to self._executable_tasks.
     """
 
-    while True:
+    while self._accepting_new_tasks:
       try:
         task_object = next(self._task_iterator)
       except StopIteration:
@@ -432,8 +449,12 @@ class TaskGraphExecutor:
       executed_task_wrapper, task_output = output
       if task_output and task_output.messages:
         for message in task_output.messages:
-          if message.topic == task.Topic.FATAL_ERROR:
+          if message.topic in (task.Topic.CHANGE_EXIT_CODE,
+                               task.Topic.FATAL_ERROR):
             self._exit_code = 1
+            if message.topic == task.Topic.FATAL_ERROR:
+              self._accepting_new_tasks = False
+
       submittable_tasks = self._task_graph.update_from_executed_task(
           executed_task_wrapper, task_output)
 
