@@ -760,6 +760,17 @@ class GRI(object):
     return re.sub(r'(:+)', r'{\1}', segment)
 
 
+def HasOverriddenEndpoint(api_name):
+  """Check if a URL is the result of an endpoint override."""
+  try:
+    endpoint_override = properties.VALUES.api_endpoint_overrides.Property(
+        api_name).Get()
+  except properties.NoSuchPropertyError:
+    return False
+
+  return bool(endpoint_override)
+
+
 class Registry(object):
   """Keep a list of all the resource collections and their parsing functions.
 
@@ -1002,17 +1013,21 @@ class Registry(object):
       raise InvalidResourceException(url, reason='unknown API host')
 
     api_name, api_version, resource_path = (
-        resource_util.SplitDefaultEndpointUrl(url))
-
-    if apis_internal.IsOverriddenURL(url):
-      # Use last registered api version in case of override.
-      api_version = self.registered_apis.get(api_name, [api_version])[-1]
+        resource_util.SplitEndpointUrl(url))
 
     try:
       # pylint:disable=protected-access
       versions = apis_internal._GetVersions(api_name)
     except apis_util.UnknownAPIError:
       raise InvalidResourceException(url, 'unknown api {}'.format(api_name))
+
+    if api_version not in versions:
+      if HasOverriddenEndpoint(api_name):
+        # Use last registered, or default, api version in case of override.
+        api_version = self.registered_apis.get(
+            # pylint:disable=protected-access
+            api_name, [apis_internal._GetDefaultVersion(api_name)])[-1]
+
     if api_version not in versions:
       raise InvalidResourceException(
           url, 'unknown api version {}'.format(api_version))
@@ -1223,7 +1238,7 @@ def GetApiBaseUrl(api_name, api_version):
       # also replaces the version, otherwise it only overrides the domain.
       # pylint:disable=protected-access
       client_class = apis_internal._GetClientClass(api_name, api_version)
-      _, url_version, _ = resource_util.SplitDefaultEndpointUrl(
+      _, url_version, _ = resource_util.SplitEndpointUrl(
           client_class.BASE_URL)
       if url_version is None:
         base_url += api_version + '/'
