@@ -42,6 +42,8 @@ auto_flags = [
     'managedConfig',
     'fleetProject',
     'enableFleet',
+    'enableSecurityPosture',
+    'enableKubeletReadonlyPort',
 ]
 
 # Change default flag values in create-auto
