@@ -59,16 +59,14 @@ class PostgreSQL(base.Command):
       parser: An argparse parser that you can use to add arguments that go on
         the command line after this command. Positional arguments are allowed.
     """
-    resource_args.AddConnectionProfileResourceArg(parser, 'to create')
+    resource_args.AddPostgresqlConnectionProfileResourceArg(parser, 'to create')
 
     cp_flags.AddNoAsyncFlag(parser)
     cp_flags.AddDisplayNameFlag(parser)
-    cp_flags.AddUsernameFlag(parser, required=True)
-    cp_flags.AddPasswordFlagGroup(parser, required=True)
-    cp_flags.AddHostFlag(parser, required=True)
-    cp_flags.AddPortFlag(parser, required=True)
+    cp_flags.AddDatabaseParamsFlags(parser)
     cp_flags.AddSslConfigGroup(parser, base.ReleaseTrack.GA)
     cp_flags.AddCloudSQLInstanceFlag(parser)
+    cp_flags.AddAlloydbClusterFlag(parser)
     flags.AddLabelsCreateFlags(parser)
 
   def Run(self, args):
